@@ -18,7 +18,7 @@ from neo.Core.State.StorageItem import StorageItem
 
 from neo.Core.TX.InvocationTransaction import InvocationTransaction
 from neo.Core.TX.TransactionAttribute import TransactionAttribute, TransactionAttributeUsage
-from neo.Core.TX.Transaction import TransactionOutput
+from neo.Core.TX.Transaction import TransactionOutput, TXFeeError
 
 from neo.SmartContract.ApplicationEngine import ApplicationEngine
 from neo.SmartContract import TriggerType
@@ -54,6 +54,9 @@ def InvokeContract(wallet, tx, fee=Fixed8.Zero(), from_addr=None, owners=None):
     except ValueError:
         print("Insufficient funds")
         return False
+    except TXFeeError as e:
+        print(e)
+        return False
 
     if wallet_tx:
 
@@ -102,6 +105,9 @@ def InvokeWithTokenVerificationScript(wallet, tx, token, fee=Fixed8.Zero(), invo
     except ValueError:
         print("Insufficient funds")
         return False
+    except TXFeeError as e:
+        print(e)
+        return False
 
     if wallet_tx:
 
@@ -309,7 +315,7 @@ def test_invoke(script, wallet, outputs, withdrawal_tx=None,
         wallet_tx = tx
     else:
         try:
-            wallet_tx = wallet.MakeTransaction(tx=tx, from_addr=from_addr)
+            wallet_tx = wallet.MakeTransaction(tx=tx, from_addr=from_addr, skip_fee_calc=True)
         except ValueError:
             pass
 
@@ -379,6 +385,14 @@ def test_invoke(script, wallet, outputs, withdrawal_tx=None,
             wallet_tx.outputs = outputs
             wallet_tx.Attributes = [] if invoke_attrs is None else deepcopy(invoke_attrs)
 
+            # calculate the required network fee for the tx and compare to fee
+            if wallet_tx.Size() > settings.MAX_FREE_TX_SIZE:
+                req_fee = Fixed8.FromDecimal(settings.FEE_PER_EXTRA_BYTE * (wallet_tx.Size() - settings.MAX_FREE_TX_SIZE))
+                if req_fee < settings.LOW_PRIORITY_THRESHOLD:
+                    req_fee = settings.LOW_PRIORITY_THRESHOLD
+                if net_fee < req_fee:
+                    net_fee = req_fee
+
             return wallet_tx, net_fee, engine.ResultStack.Items, engine.ops_processed, success
 
         # this allows you to to test invocations that fail
@@ -421,7 +435,7 @@ def test_deploy_and_invoke(deploy_script, invoke_args, wallet,
 
     try:
         dtx = wallet.MakeTransaction(tx=dtx, from_addr=from_addr)
-    except ValueError:
+    except (ValueError, TXFeeError):
         pass
 
     context = ContractParametersContext(dtx)
@@ -544,7 +558,7 @@ def test_deploy_and_invoke(deploy_script, invoke_args, wallet,
 
         try:
             itx = wallet.MakeTransaction(tx=itx, from_addr=from_addr)
-        except ValueError:
+        except (ValueError, TXFeeError):
             pass
 
         context = ContractParametersContext(itx)
