@@ -160,6 +160,7 @@ class CommandSCTestInvoke(CommandBase):
             return False
 
         arguments, from_addr = PromptUtils.get_from_addr(arguments)
+        arguments, priority_fee = PromptUtils.get_fee(arguments)
         arguments, invoke_attrs = PromptUtils.get_tx_attr_from_args(arguments)
         arguments, owners = PromptUtils.get_owners_from_params(arguments)
 
@@ -175,6 +176,13 @@ class CommandSCTestInvoke(CommandBase):
             print("Invalid script hash")
             return False
 
+        p_fee = Fixed8.Zero()
+        if priority_fee is not None:
+            p_fee = priority_fee
+            if p_fee is False:
+                logger.debug("invalid fee")
+                return False
+
         tx, fee, results, num_ops, engine_success = TestInvokeContract(wallet, arguments, from_addr=from_addr, invoke_attrs=invoke_attrs, owners=owners)
         if tx and results:
 
@@ -189,7 +197,10 @@ class CommandSCTestInvoke(CommandBase):
             print(f"Invoke TX fee: {fee.value / Fixed8.D}")
             print(
                 "-------------------------------------------------------------------------------------------------------------------------------------\n")
-            print("Enter your password to continue and invoke on the network\n")
+            comb_fee = p_fee + fee
+            if comb_fee != fee:
+                print(f"Priority Fee ({p_fee.value / Fixed8.D}) + Invoke TX Fee ({fee.value / Fixed8.D}) = {comb_fee.value / Fixed8.D}\n")
+            print("Enter your password to continue and deploy this contract")
 
             tx.Attributes = invoke_attrs
 
@@ -197,7 +208,7 @@ class CommandSCTestInvoke(CommandBase):
             if not wallet.ValidatePassword(passwd):
                 return print("Incorrect password")
 
-            return InvokeContract(wallet, tx, fee, from_addr=from_addr, owners=owners)
+            return InvokeContract(wallet, tx, comb_fee, from_addr=from_addr, owners=owners)
         else:
             print("Error testing contract invoke")
             return False
@@ -209,8 +220,9 @@ class CommandSCTestInvoke(CommandBase):
         p4 = ParameterDesc('--attach-gas', 'amount of gas to attach to the transaction. Required if --attach-neo is not specified', optional=True)
         p5 = ParameterDesc('--no-parse-addr', 'flag to turn off address parsing when input into the smart contract', optional=True)
         p6 = ParameterDesc('--from-addr', 'source address to take fee funds from (if not specified, take first address in wallet)', optional=True)
-        p7 = ParameterDesc('--owners', 'list of NEO addresses indicating the transaction owners e.g. --owners=[address1,address2]', optional=True)
-        p8 = ParameterDesc('--tx-attr',
+        p7 = ParameterDesc('--fee', 'Attach GAS amount to give your transaction priority (> 0.001) e.g. --fee=0.01', optional=True)
+        p8 = ParameterDesc('--owners', 'list of NEO addresses indicating the transaction owners e.g. --owners=[address1,address2]', optional=True)
+        p9 = ParameterDesc('--tx-attr',
                            'a list of transaction attributes to attach to the transaction\n\n'
                            f"{' ':>17} See: http://docs.neo.org/en-us/network/network-protocol.html section 4 for a description of possible attributes\n\n"
                            f"{' ':>17} Example\n"
@@ -219,7 +231,7 @@ class CommandSCTestInvoke(CommandBase):
                            f"{' ':>17} For more information about parameter types see\n"
                            f"{' ':>17} https://neo-python.readthedocs.io/en/latest/data-types.html#contractparametertypes\n", optional=True)
 
-        params = [p1, p2, p3, p4, p5, p6, p7, p8]
+        params = [p1, p2, p3, p4, p5, p6, p7, p8, p9]
         return CommandDesc('invoke', 'Call functions on the smart contract. Will prompt before sending to the network', params=params)
 
 
@@ -233,11 +245,19 @@ class CommandSCDeploy(CommandBase):
             print("Please open a wallet")
             return False
 
-        if len(arguments) < 6:
+        if len(arguments) < 5:
             print("Please specify the required parameters")
             return False
 
         args, from_addr = PromptUtils.get_from_addr(arguments)
+        arguments, priority_fee = PromptUtils.get_fee(arguments)
+
+        p_fee = Fixed8.Zero()
+        if priority_fee is not None:
+            p_fee = priority_fee
+            if p_fee is False:
+                logger.debug("invalid fee")
+                return False
 
         path = args[0]
 
@@ -276,6 +296,9 @@ class CommandSCDeploy(CommandBase):
             print(f"Deploy Invoke TX Fee: {fee.value / Fixed8.D}")
             print(
                 "-------------------------------------------------------------------------------------------------------------------------------------\n")
+            comb_fee = p_fee + fee
+            if comb_fee != fee:
+                print(f"Priority Fee ({p_fee.value / Fixed8.D}) + Deploy Invoke TX Fee ({fee.value / Fixed8.D}) = {comb_fee.value / Fixed8.D}\n")
             print("Enter your password to continue and deploy this contract")
 
             passwd = prompt("[password]> ", is_password=True)
@@ -283,7 +306,7 @@ class CommandSCDeploy(CommandBase):
                 print("Incorrect password")
                 return False
 
-            return InvokeContract(wallet, tx, Fixed8.Zero(), from_addr=from_addr)
+            return InvokeContract(wallet, tx, comb_fee, from_addr=from_addr)
         else:
             print("Test invoke failed")
             print(f"TX is {tx}, results are {results}")
@@ -299,8 +322,8 @@ class CommandSCDeploy(CommandBase):
                            f"the return type of the smart contract output\n\n"
                            f"{' ':>17} For more information about parameter types see\n"
                            f"{' ':>17} https://neo-python.readthedocs.io/en/latest/data-types.html#contractparametertypes\n", optional=True)
-
-        params = [p1, p2, p3, p4, p5, p6]
+        p7 = ParameterDesc('--fee', 'Attach GAS amount to give your transaction priority (> 0.001) e.g. --fee=0.01', optional=True)
+        params = [p1, p2, p3, p4, p5, p6, p7]
         return CommandDesc('deploy', 'Deploy a smart contract (.avm) file to the blockchain', params=params)
 
 
