@@ -1,7 +1,3 @@
-import binascii
-
-from logzero import logger
-
 from neo.SmartContract.ApplicationEngine import ApplicationEngine
 from neo.VM.InteropService import InteropService
 from neo.SmartContract.Contract import Contract
@@ -31,6 +27,9 @@ from neo.Core.State.ContractState import ContractState
 from neo.Core.State.AccountState import AccountState
 from neo.Core.State.AssetState import AssetState
 from neo.Core.State.StorageItem import StorageItem
+from neo.logging import log_manager
+
+logger = log_manager.getLogger('vm')
 
 
 class StateReader(InteropService):
@@ -125,7 +124,9 @@ class StateReader(InteropService):
         self.Register("Neo.Transaction.GetOutputs", self.Transaction_GetOutputs)
         self.Register("Neo.Transaction.GetReferences", self.Transaction_GetReferences)
         self.Register("Neo.Transaction.GetUnspentCoins", self.Transaction_GetUnspentCoins)
+        self.Register("Neo.Transaction.GetWitnesses", self.Transaction_GetWitnesses)
         self.Register("Neo.InvocationTransaction.GetScript", self.InvocationTransaction_GetScript)
+        self.Register("Neo.Witness.GetVerificationScript", self.Witness_GetVerificationScript)
         self.Register("Neo.Attribute.GetUsage", self.Attribute_GetUsage)
         self.Register("Neo.Attribute.GetData", self.Attribute_GetData)
         self.Register("Neo.Input.GetHash", self.Input_GetHash)
@@ -294,8 +295,17 @@ class StateReader(InteropService):
                                                                   height, tx_hash, success, engine.testMode))
 
         else:
+            # when a contract exits in a faulted state
+            # we should display that in the notification
+            if not error:
+                error = 'Execution exited in a faulted state. Any payload besides this message contained in this event is the contents of the EvaluationStack of the current script context.'
+
             payload.Value.append(ContractParameter(ContractParameterType.String, error))
-            payload.Value.append(ContractParameter(ContractParameterType.String, engine._VMState))
+
+            # If we do not add the eval stack, then exceptions that are raised in a contract
+            # are not displayed to the event consumer
+            [payload.Value.append(ContractParameter.ToParameter(item)) for item in engine.CurrentContext.EvaluationStack.Items]
+
             if engine.Trigger == Application:
                 self.events_to_dispatch.append(
                     SmartContractEvent(SmartContractEvent.EXECUTION_FAIL, payload,
@@ -429,8 +439,9 @@ class StateReader(InteropService):
         try:
             stack_item = StackItem.DeserializeStackItem(reader)
             engine.CurrentContext.EvaluationStack.PushT(stack_item)
-        except Exception as e:
-            logger.error("Could not Deserialize stack item: %s " % e)
+        except ValueError as e:
+            # can't deserialize type
+            logger.error("%s " % e)
             return False
         return True
 
@@ -742,6 +753,19 @@ class StateReader(InteropService):
         engine.CurrentContext.EvaluationStack.PushT(refs)
         return True
 
+    def Transaction_GetWitnesses(self, engine: ExecutionEngine):
+        tx = engine.CurrentContext.EvaluationStack.Pop().GetInterface()
+
+        if tx is None:
+            return False
+
+        if len(tx.scripts) > ApplicationEngine.maxArraySize:
+            return False
+
+        witnesses = [StackItem.FromInterface(s) for s in tx.scripts]
+        engine.CurrentContext.EvaluationStack.PushT(witnesses)
+        return True
+
     def InvocationTransaction_GetScript(self, engine: ExecutionEngine):
         tx = engine.CurrentContext.EvaluationStack.Pop().GetInterface()
         if tx is None:
@@ -749,6 +773,13 @@ class StateReader(InteropService):
         engine.CurrentContext.EvaluationStack.PushT(tx.Script)
         return True
 
+    def Witness_GetVerificationScript(self, engine: ExecutionEngine):
+        witness = engine.CurrentContext.EvaluationStack.Pop().GetInterface()
+        if witness is None:
+            return False
+        engine.CurrentContext.EvaluationStack.PushT(witness.VerificationScript)
+        return True
+
     def Attribute_GetUsage(self, engine: ExecutionEngine):
         attr = engine.CurrentContext.EvaluationStack.Pop().GetInterface()
         if attr is None:
