@@ -1,11 +1,11 @@
-from unittest import TestCase
+from unittest import TestCase, skip
 import pexpect
 
 
 class PromptTest(TestCase):
 
+    @skip("Unreliable due to system resource dependency. Replace later with better alternative")
     def test_prompt_run(self):
-
         child = pexpect.spawn('python neo/bin/prompt.py')
         child.expect([pexpect.EOF, pexpect.TIMEOUT], timeout=10)  # if test is failing consider increasing timeout time
         before = child.before
@@ -14,8 +14,8 @@ class PromptTest(TestCase):
         self.assertIn(checktext, text)
         child.terminate()
 
+    @skip("Unreliable due to system resource dependency. Replace later with better alternative")
     def test_prompt_open_wallet(self):
-
         child = pexpect.spawn('python neo/bin/prompt.py')
         child.send('open wallet fixtures/testwallet.db3\n')
         child.send('testpassword\n')
